@@ -2,8 +2,12 @@ import abc
 import dataclasses
 import functools
 from typing import Any
+from typing import Awaitable
 from typing import Dict
+from typing import Generic
 from typing import Optional
+from typing import TypeVar
+from typing import Union
 
 
 @dataclasses.dataclass
@@ -35,6 +39,18 @@ class TestCaseConfig:
     repeat_num_times: Optional[int] = None
 
 
+@dataclasses.dataclass
+class HumanReviewField:
+    name: str
+    value: str
+
+    def serialize(self) -> Dict[str, str]:
+        return dict(
+            name=self.name,
+            value=self.value,
+        )
+
+
 class BaseTestCase(abc.ABC):
     @abc.abstractmethod
     def hash(self) -> str:
@@ -43,16 +59,26 @@ class BaseTestCase(abc.ABC):
         """
         pass
 
+    def serialize_for_human_review(self) -> Optional[list[HumanReviewField]]:
+        """
+        Can be overridden to customize how the test case is displayed in Autoblocks Human Review,
+        e.g. to add, remove, or transform fields.
+        """
+        return None
+
+
+TestCaseType = TypeVar("TestCaseType", bound=BaseTestCase)
+
 
 @dataclasses.dataclass
-class TestCaseContext:
+class TestCaseContext(Generic[TestCaseType]):
     """
     This class serves as a container for the user's test case +
     utilities around that test case.
     """
 
     # The user's test case
-    test_case: BaseTestCase
+    test_case: TestCaseType
 
     # Defined if the user has configured their test case to repeat
     repetition_idx: Optional[int]
@@ -90,7 +116,11 @@ class BaseTestEvaluator(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def evaluate_test_case(self, test_case: BaseTestCase, output: Any) -> Optional[Evaluation]:
+    def evaluate_test_case(
+        self,
+        *args: Any,
+        **kwargs: Any,
+    ) -> Union[Optional[Evaluation], Awaitable[Optional[Evaluation]]]:
         pass
 
 
@@ -113,11 +143,15 @@ class BaseEventEvaluator(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def evaluate_event(self, event: TracerEvent) -> Optional[Evaluation]:
+    def evaluate_event(self, event: TracerEvent) -> Union[Optional[Evaluation], Awaitable[Optional[Evaluation]]]:
         pass
 
 
-class BaseEvaluator(BaseTestEvaluator, BaseEventEvaluator, abc.ABC):
+class BaseEvaluator(
+    BaseTestEvaluator,
+    BaseEventEvaluator,
+    abc.ABC,
+):
     """
     An ABC for users that are implementing an evaluator that will be run against both test cases and production events.
     """
