@@ -4,13 +4,12 @@ import dataclasses
 import inspect
 import logging
 import uuid
-from datetime import datetime
 from datetime import timedelta
-from datetime import timezone
 from typing import Any
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Sequence
 from typing import Tuple
 from typing import Union
 
@@ -24,6 +23,7 @@ from autoblocks._impl.util import AnyTask
 from autoblocks._impl.util import AutoblocksEnvVar
 from autoblocks._impl.util import all_settled
 from autoblocks._impl.util import get_running_loop
+from autoblocks._impl.util import now_iso_8601
 
 log = logging.getLogger(__name__)
 
@@ -139,7 +139,7 @@ class AutoblocksTracer:
                 ctx = contextvars.copy_context()
                 return await global_state.event_loop().run_in_executor(
                     None,
-                    ctx.run,
+                    ctx.run,  # type: ignore
                     evaluator.evaluate_event,
                     event,
                 )
@@ -160,7 +160,7 @@ class AutoblocksTracer:
     async def _run_evaluators_unsafe(
         self,
         event: TracerEvent,
-        evaluators: List[BaseEventEvaluator],
+        evaluators: Sequence[BaseEventEvaluator],
     ) -> List[Dict[str, Any]]:
         """
         Run a list of evaluators on an event and return the evaluations as a list of dictionaries.
@@ -188,7 +188,7 @@ class AutoblocksTracer:
     async def _async_send_event(
         self,
         payload: Payload,
-        evaluators: Optional[List[BaseEventEvaluator]],
+        evaluators: Optional[Sequence[BaseEventEvaluator]],
     ) -> None:
         # If there are evaluators, run them and compute the evaluations property
         if evaluators:
@@ -279,7 +279,7 @@ class AutoblocksTracer:
         prompt_tracking: Optional[Dict[str, Any]],
     ) -> Payload:
         trace_id = trace_id or self._trace_id
-        timestamp = timestamp or datetime.now(timezone.utc).isoformat()
+        timestamp = timestamp or now_iso_8601()
 
         merged_properties = dict(self._properties)
         merged_properties.update(properties or {})
@@ -302,7 +302,7 @@ class AutoblocksTracer:
     def _dispatch_event_unsafe(
         self,
         payload: Payload,
-        evaluators: Optional[List[BaseEventEvaluator]],
+        evaluators: Optional[Sequence[BaseEventEvaluator]],
     ) -> None:
         task: AnyTask
 
@@ -346,7 +346,7 @@ class AutoblocksTracer:
         parent_span_id: Optional[str] = None,
         timestamp: Optional[str] = None,
         properties: Optional[Dict[str, Any]] = None,
-        evaluators: Optional[List[BaseEventEvaluator]] = None,
+        evaluators: Optional[Sequence[BaseEventEvaluator]] = None,
         prompt_tracking: Optional[Dict[str, Any]] = None,
     ) -> None:
         """
