@@ -3,6 +3,8 @@ import logging
 import os
 import urllib.parse
 from concurrent.futures import Future
+from datetime import datetime
+from datetime import timezone
 from enum import Enum
 from typing import Any
 from typing import Coroutine
@@ -23,10 +25,13 @@ class StrEnum(str, Enum):
 
 
 class AutoblocksEnvVar(StrEnum):
+    ALIGN_TEST_CASE_HASH = "AUTOBLOCKS_ALIGN_TEST_CASE_HASH"
+    ALIGN_TEST_EXTERNAL_ID = "AUTOBLOCKS_ALIGN_TEST_EXTERNAL_ID"
     API_KEY = "AUTOBLOCKS_API_KEY"
     CLI_SERVER_ADDRESS = "AUTOBLOCKS_CLI_SERVER_ADDRESS"
     INGESTION_KEY = "AUTOBLOCKS_INGESTION_KEY"
-    PROMPT_SNAPSHOTS = "AUTOBLOCKS_PROMPT_SNAPSHOTS"
+    PROMPT_REVISIONS = "AUTOBLOCKS_PROMPT_REVISIONS"
+    CONFIG_REVISIONS = "AUTOBLOCKS_CONFIG_REVISIONS"
     TRACER_THROW_ON_ERROR = "AUTOBLOCKS_TRACER_THROW_ON_ERROR"
 
     def get(self) -> Optional[str]:
@@ -61,3 +66,7 @@ def get_running_loop() -> Optional[asyncio.AbstractEventLoop]:
         return asyncio.get_running_loop()
     except RuntimeError:
         return None
+
+
+def now_iso_8601() -> str:
+    return datetime.now(timezone.utc).isoformat()
